'use strict';

exports.__esModule = true;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _Form = require('material-ui/Form');

var _Checkbox = require('material-ui/Checkbox');

var _Checkbox2 = _interopRequireDefault(_Checkbox);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function CheckboxesGroupWidget(props) {
    function selectValue(value, selected, all) {
        var at = all.indexOf(value);
        var updated = selected.slice(0, at).concat(value, selected.slice(at));
        // As inserting values at predefined index positions doesn't work with empty
        // arrays, we need to reorder the updated selection to match the initial order
        return updated.sort(function (a, b) {
            return all.indexOf(a) > all.indexOf(b);
        });
    }

    function deselectValue(value, selected) {
        return selected.filter(function (v) {
            return v !== value;
        });
    }

    var label = props.label,
        value = props.value,
        readonly = props.readonly,
        disabled = props.disabled,
        autofocus = props.autofocus,
        onBlur = props.onBlur,
        onFocus = props.onFocus,
        options = props.options,
        _onChange = props.onChange,
        schema = props.schema,
        formContext = props.formContext,
        registry = props.registry,
        otherProps = _objectWithoutProperties(props, ['label', 'value', 'readonly', 'disabled', 'autofocus', 'onBlur', 'onFocus', 'options', 'onChange', 'schema', 'formContext', 'registry']);

    var title = schema.title;
    var enumOptions = options.enumOptions,
        inline = options.inline;


    return _react2.default.createElement(
        _Form.FormControl,
        { component: 'fieldset' },
        _react2.default.createElement(
            _Form.FormLabel,
            { component: 'legend' },
            label || title
        ),
        _react2.default.createElement(
            _Form.FormGroup,
            null,
            enumOptions.map(function (option, index) {
                var checked = value && value.indexOf(option.value) !== -1;

                return _react2.default.createElement(_Form.FormControlLabel, {
                    key: index,
                    disabled: disabled || readonly,
                    value: option.value,
                    label: option.label,
                    control: _react2.default.createElement(_Checkbox2.default, {
                        checked: checked,
                        onChange: function onChange(event) {
                            var all = enumOptions.map(function (_ref) {
                                var value = _ref.value;
                                return value;
                            });
                            var newValue = event.target.checked ? selectValue(option.value, value, all) : deselectValue(option.value, value);

                            _onChange(newValue);
                        },
                        value: value
                    })
                });
            })
        )
    );
}

CheckboxesGroupWidget.defaultProps = {
    autofocus: false,
    options: {
        inline: false
    }
};

CheckboxesGroupWidget.propTypes = process.env.NODE_ENV !== "production" ? {
    schema: _propTypes2.default.object.isRequired,
    id: _propTypes2.default.string.isRequired,
    options: _propTypes2.default.shape({
        enumOptions: _propTypes2.default.array,
        inline: _propTypes2.default.bool
    }).isRequired,
    value: _propTypes2.default.any,
    required: _propTypes2.default.bool,
    readonly: _propTypes2.default.bool,
    disabled: _propTypes2.default.bool,
    multiple: _propTypes2.default.bool,
    autofocus: _propTypes2.default.bool,
    onChange: _propTypes2.default.func
} : {};

exports.default = CheckboxesGroupWidget;
module.exports = exports['default'];